@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding=utf8
 
-__version__ = '3.0.2.2'
+__version__ = '3.0.2.3'
 
 import re
 
@@ -154,7 +154,8 @@ class Bootstrap(object):
 
         jquery = lwrap(
             WebCDN('//cdnjs.cloudflare.com/ajax/libs/jquery/%s/'
-                   % JQUERY_VERSION))
+                   % JQUERY_VERSION),
+            local)
 
         html5shiv = lwrap(
             WebCDN('//cdnjs.cloudflare.com/ajax/libs/html5shiv/%s/'
